GroupManagerAndroid class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callNativeMethod(
String method, [dynamic params]) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateNativeHandler(
Future handler(MethodCall call)?) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited